//
//  TableViewController.swift
//  Weather
//
//  Created by Mark Meretzky on 10/26/17.
//  Copyright © 2017 NYU School of Professional Studies. All rights reserved.
//

import UIKit

class TableViewController: UITableViewController {
	let cellReuseIdentifier: String = "temperatures";
	var lines: [String] = [];   //array of Strings, initially empty
	
	required init(coder aDecoder: NSCoder) {
		super.init(nibName: nil, bundle: nil);
		
		let appid: String = "532d313d6a9ec4ea93eb89696983e369";//"92a0b81218fc51a38a717d1aed2b4a22";
		let urlString: String = "http://api.openweathermap.org/data/2.5/forecast/daily"
			+ "?q=10003,US"     //New York City
			+ "&cnt=7"          //number of days
			+ "&units=imperial" //fahrenheit, not celsius
			+ "&mode=json"      //vs. xml or html
			+ "&APPID=\(appid)";
		
		let url: URL? = URL(string: urlString);
		if url == nil {
			print("could not create URL");
			return;
		}
		
		let formatter = DateFormatter();
		formatter.dateStyle = DateFormatter.Style.long;
		
		let sharedSession: URLSession = URLSession.shared;
		
		let downloadTask: URLSessionDownloadTask = sharedSession.downloadTask(
			with: url!,
			completionHandler: {(filename: URL?, response: URLResponse?, error: Error?) in
				
				if (error != nil) {
					print("could not download data from server: \(error!)");
					return;
				}
				
				//Arrive here when the data from the forecast server has been
				//downloaded into a file in the iPhone.
				
				//Copy the data from the file into a Data object.
				let data: Data;
				do {
					try data = Data(contentsOf: filename!);
				} catch {
					print("could not create Data object");
					return;
				}
				
				//The data is in JSON format.
				//Copy the data from the Data object into a big Swift dictionary.
				let dictionary: [String: Any];
				do {
					try dictionary =
						JSONSerialization.jsonObject(with: data, options: JSONSerialization.ReadingOptions())
						as! [String: Any];
				} catch {
					print("could not create big dictionary: \(error)");
					return;
				}
				
				//print(dictionary); //the JSON downloaded from the server
				
				//week is an array of dictionaries.
				let week: [[String: Any]] = dictionary["list"] as! [[String: Any]];
				
				for day: [String: Any] in week {
					let dt: Int = day["dt"] as! Int;
					let date: Date = Date(timeIntervalSince1970: TimeInterval(dt));
					let dateString = formatter.string(from: date);
					let temp: [String: Float] = day["temp"] as! [String: Float];
					let max: Float = temp["max"]!;
					self.lines.append("\(dateString) \(max)° F");
				}
				
				//self.tableView.reloadData();	//was delayed

				DispatchQueue.main.async(execute: {() -> Void in
					self.tableView.reloadData();
				});
		});
		
		downloadTask.resume();
	}

    override func viewDidLoad() {
        super.viewDidLoad();
		tableView.register(UITableViewCell.self, forCellReuseIdentifier: cellReuseIdentifier);
		
		//Default values for some of the properties of class UIScrollView.
		tableView.bounces = true;
		tableView.scrollsToTop = true;	//when user taps the status bar
		tableView.decelerationRate = UIScrollViewDecelerationRateNormal; //friction

        // Uncomment the following line to preserve selection between presentations
        // self.clearsSelectionOnViewWillAppear = false

        // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
        // self.navigationItem.rightBarButtonItem = self.editButtonItem
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

	override func numberOfSections(in tableView: UITableView) -> Int {
		return 1;
    }
	
	override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
		assert(section == 0);
		return lines.count;
	}


    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: cellReuseIdentifier, for: indexPath)

        // Configure the cell...
		assert(cell.textLabel != nil);
		cell.textLabel!.text = lines[indexPath.row];

        return cell
    }

    /*
    // Override to support conditional editing of the table view.
    override func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
        // Return false if you do not want the specified item to be editable.
        return true
    }
    */

    /*
    // Override to support editing the table view.
    override func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
        if editingStyle == .delete {
            // Delete the row from the data source
            tableView.deleteRows(at: [indexPath], with: .fade)
        } else if editingStyle == .insert {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }    
    }
    */

    /*
    // Override to support rearranging the table view.
    override func tableView(_ tableView: UITableView, moveRowAt fromIndexPath: IndexPath, to: IndexPath) {

    }
    */

    /*
    // Override to support conditional rearranging of the table view.
    override func tableView(_ tableView: UITableView, canMoveRowAt indexPath: IndexPath) -> Bool {
        // Return false if you do not want the item to be re-orderable.
        return true
    }
    */

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
